<?php

/**
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

namespace OCA\SideMenu\Appinfo;

use OC\Security\CSP\ContentSecurityPolicy;
use OCP\Util;
use OCP\IUserSession;

$config = \OC::$server->getConfig();
$cspnm = \OC::$server->getContentSecurityPolicyNonceManager();
$user = \OC::$server[IUserSession::class]->getUser();

$enabled = true;

if ($user !== null) {
    $enabled = (bool) $config->getUserValue($user->getUid(), 'side_menu', 'enabled', '1');
}

if ($enabled) {
    Util::addScript('side_menu', 'sideMenu');
    Util::addStyle('side_menu', 'sideMenu');

    $stylesheet = \OC::$server->getURLGenerator()->linkToRoute(
        'side_menu.Css.stylesheet',
        [
            'v' => $config->getAppValue('side_menu', 'cache', '0'),
        ]
    );

    $script = \OC::$server->getURLGenerator()->linkToRoute(
        'side_menu.Js.script',
        [
            'v' => $config->getAppValue('side_menu', 'cache', '0'),
        ]
    );

    Util::addHeader(
        'link',
        [
            'href' => $stylesheet,
            'rel' => 'stylesheet'
        ],
        ''
    );

    Util::addHeader(
        'script',
        [
            'src' => $script,
            'nonce' => $cspnm->getNonce(),
        ],
        ''
    );
}
